# Association between individuals' sodium intake and their consumption of snacks and preserves

library(tidyverse)

# Load the data
metaFP <- "parkinsons_metadata.txt"
meta <- read_delim(metaFP, delim="\t")

# prepare the data by removing NAs and zeros and any Na value above 5000
filtered_meta <- meta %>%
  filter(!is.na(Sodium), !is.na(Meat),
         Sodium!=0, Meat!=0, Sodium < 5000)

# Check the distribution of the two variables (both are left-skewed)
Sodium_distribution <- hist(filtered_meta$Sodium, main="Histogram",breaks = 30)
Snacks_distribution <- hist(filtered_meta$Soups_sauces, main="Histogram",breaks = 30)


# Check the correlation using spearman
ggplot(data = filtered_meta
       , mapping = aes(x=filtered_meta$Soups_sauces, y=filtered_meta$Sodium)) +
  geom_point() +
  geom_smooth(method = "lm")


cor.test(filtered_meta$Soups_sauces, filtered_meta$Sodium, method="spearman")

